
## Introduction

Welcome to **Proscenium**, a Tabletop Role-Playing Game designed to be approachable, inclusive, and extensible.

In this document, terms will be **Bolded** where they are formally defined, and *Italicized* otherwise. If you see an *Italicized* word that you don't recognize yet, fear not! It is likely going to be defined shortly.

## Sitting Down to Play

### Table

Your **Table** is your storytelling sanctuary.

At your Table are the *Players* who control their *Characters*, and the *Director* who facilitates the game session and controls non-player characters (NPCs). In other systems, the Director may be known as the "Game Master."

### Director

The **Director** weaves *Player* actions into a cohesive story.

The Director's job is to run the table and ensure that everyone is having fun and feeling safe to explore and express themselves.

As the Director, you play the role of every non-player character (**NPC**) in the world, and are responsible for their decisions, actions and rolls.

### Players

The **Players** drive the story forward. They are the central focus of the game as they control their *Characters*, explore the world, and grow as a party.

As a Player, you have agency to move and act within the fiction of the story. You are an equal participant in the storytelling and are in charge of bringing your character to life with the help of the other Players and your *Director*.

Players say what they want their Character to do, and the Director will determine how those actions will be resolved. Players can do just about anything you can think of, so long as it makes sense within the context of the current scene.

### Scenes

A **Scene** is the current segment of the story being told at the table. A new Scene begins when the *Leading Characters* make a decision to move on from a location, or when the *Director* invokes that time is passing.

### Respect the Shared Fiction

Proscenium is designed to facilitate the telling of collaborative stories through it's system. Because of this, some things which other systems may track or monitor are instead managed "In Fiction." This means that the *Director* and *Players* should respect the story and its impact on gameplay just as much as the rules and their impacts.

## Characters

**Characters** are the people, animals, entities, and beings whose decisions and actions impact the story.

**Non-Player Characters** (or, "*NPCs*") are Characters under the control of the *Director*. These may be friends, foes, or just some random guy digging a big hole. Rock on, big hole guy.

**Leading Characters** (or, "*Leads*") are Characters controlled by the *Players*. They differ from *NPCs* in that they have independent autonomy from the *Director*, as well as having a bit more of a buffer between themselves and certain doom. Just a light bit of plot armor, if you will.

Each Character has a variety of attributes, including their *Species*, *Stats*, and *Talents*.

### Species

The **Species** of a *Character* determines their physical appearance as well as their starting *Abilities*, *Stats* and *Talent Prowess*.

### Stats

**Stats** are properties of a *Character* which describe the extent of their ability to adventure.

There are four stats for each Character:

| Stat                  | Abbreviation | Description                                                 | Starting Maximum |
| --------------------- | ------------ | ----------------------------------------------------------- | ---------------- |
| **Health Points**     | HP           | How much *Damage* you can sustain before becoming *Dropped* | 10               |
| **Skill Points**      | SP           | How many *Skills* you can use before needing to *Rest*      | 5                |
| **Exhaustion Points** | EP           | How far you can push yourself during adventure              | 2                |
| **Experience Points** | XP           | Used to enhance your Character's abilities                  | 12               |

### Talents

A **Talent** is a representation of a *Character*'s *Prowess*. Talents are used when making *Rolls* to see how your Character fares in a situation.

Each of your Character's Talents may be **Novice** (1d20), **Adept** (2d20), or **Master** (3d20).

There are six talents:

| Talent        | Use                                                                                                                                                        |
| ------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Muscle**    | Performing physically intensive tasks or leveraging the natural resilience of your body                                                                    |
| **Focus**     | Reading subtleties, picking up hints, tracking your prey, or making determinations                                                                         |
| **Knowledge** | Deciphering language, recalling history or generally having book smarts                                                                                    |
| **Charm**     | Swaying hearts, performing for an audience, or generally being a likable.                                                                                  |
| **Cunning**   | Deception, quick thinking, deft actions, and survival instinct                                                                                             |
| **Spark**     | Prowess in supernatural or otherworldly powers<br><br>In the default setting, Spark is used for spells, arcane abilities, and general connection to magic. |

## Dice & Rolling

We're here to roll dice and tell stories based on chaos. Let's talk about the first part. The chaos will come naturally.

### Making a Roll

**Rolls** determine the outcome of complex *Character* actions in a *Scene*. Perhaps you are attempting to jump across a large chasm, or trying to haggle on the price of a rare weapon.

In Proscenium, you typically roll one, two, or three 20-sided dice (D20) to determine how your actions play out.

### 1. Determine the Talent

Determine which *Talent* you will roll with. If you are attacking with a weapon or using a Skill, the Equipment or Skill may specify which Talent to use. Otherwise, consult with the *Director* to agree on which Talent best fits the scenario.

| Talent        | Use                                               |
| ------------- | ------------------------------------------------- |
| **Muscle**    | Feats of strength                                 |
| **Focus**     | Concentration and deduction                       |
| **Knowledge** | Smarts and history                                |
| **Charm**     | Socializing, performing, and convincing           |
| **Cunning**   | Spinning lies, sleight of hand, survival instinct |
| **Spark**     | Supernatural actions and magic                    |

### 2. Collect Your Dice

Your *Prowess* in the chosen Talent informs how many 20-sided dice (D20) to roll.

| Prowess    | Number of D20s to Roll |
| ---------- | ---------------------- |
| **Novice** | 1                      |
| **Adept**  | 2                      |
| **Master** | 3                      |

### 3. Note the Challenge

The Director will tell you what the *Challenge* of the roll is.

If your *Prowess* does not match or exceed the *Challenge* of a roll, you will incur a negative side effect even when succeeding your roll.

| Challenge      | Description                                                                            | Minimum Successful Roll |
| -------------- | -------------------------------------------------------------------------------------- | ----------------------- |
| **Novice**     | Something most anyone could reasonably accomplish with or without training             | 5                       |
| **Adept**      | A task that would be trivial for an experienced Character, but difficult without it    | 11                      |
| **Master**     | A daunting task with higher risks, suited for those who are confident in their ability | 16                      |
| **Theatrical** | A nearly-impossible feat, reserved only for the most epic moments in your tale         | 20                      |

### 4. Make the Roll

Roll the dice! Note the highest single number from all of the dice you roll. For example, if you rolled three dice resulting in 6, 17, and 11, you would use the 17 as your roll.

If you meet or exceed the minimum successful roll for the *Challenge* level, your roll is a **Success** and you accomplish your task. Otherwise, it is a **Mishap**, and things go awry!

Additionally, if your *Prowess* was less than the *Challenge* of the roll, you incur an additional **Complication** from the *Director*, regardless of success. It's best to focus on your strong suits, but sometimes reaching for a harder challenge may be worth it despite the risks!

*Skills* and *Equipment* may specify unique effects that occur on *Successes* or *Mishaps*.

### Fate Roll

A **Fate Roll** occurs when a scenario does not call for any *Talent*, or is completely outside the control of any *Player*. Fate Rolls are a single D20 and must roll at least an *11* to succeed unless otherwise specified by a piece of *Equipment*, a *Skill*, or a game rule.

### Contest Roll

A **Contest Roll** is when two characters in a scene roll for the same Talent and compare results. Whoever's outcome is higher is the winner of the Contest Roll.

In the event that the results are equal, roll again until a victor is determined.

### Consider a Twist

The *Director* may choose to **Propose a Twist** to a *Player* who is about to make a roll.

A *Twist* is an offer to reduce the *Challenge* of a roll in exchange for adding an additional *Complication*. If a Player a proposed Twist for a roll that would already create one Complication, the Twist can still add a second Complication.

Players do not need to take the offered Twist, and the *Director* chooses when a Twist is possible.

## Methods & Skills

### Methods

**Methods** are collections of *Skills* which you may unlock to enhance and customize your character. Any character may unlock Skills from any Method, provided you have the available *Experience Points* and meet any prerequisites.

You may choose to unlock *Skills* from *Methods* whenever you find *Respite*.

The Skill becomes immediately available after your Respite concludes.

### Method Ranks

*Methods* contain groups of *Skills* called **Ranks**. Skills may only be unlocked if they are in the first Rank, or if you have unlocked at least one Skill from the previous Rank.

For example, if a Method has a Rank 4 Skill you would like to unlock, you must first unlock a Rank 1, Rank 2, and Rank 3 Skill from that Method.

You do not need to unlock every Skill in each Rank before moving to the next Rank.

### Types of Skills

There are three types of *Skills* in Proscenium:

| Skill Type | Description                                                                                                                                                     |
| ---------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Action** | Actions  can be invoked at will, provided you have the available resources.                                                                                     |
| **Cue**    | Cues can be invoked only once a condition has been met. For example, a Cue may empower you to perform a counter-attack after a melee *Basic Attack* misses you. |
| **Trait**  | Traits are passive Skills which grant a constant modifier, usually some kind of boon.                                                                           |

## Props, Equipment & Economy

**Equipment** in *Proscenium* are pieces of gear you can wield or use. They are found during your adventure hidden as treasure, on the shelf at a shop, or packed away in the caravan of a traveling merchant.

### The Minutia is a Given

Proscenium does not have a mechanism for tracking things which would be considered basic adventuring gear, food, or drink. Instead, these are to be handled "in fiction," letting the story drive the circumstances.

For example, if our *Leading Characters* are lost in an expansive desert for days on end, it would not make sense for them to have an unlimited supply of food and water. But if the party just left town, it's safe to assume they grabbed some food on the way out.

### Reach for a Prop

Sometimes, the *Leads* will need a simple item like rope, a small knife, or a candle. These are called **Props**, and are handled separately from *Equipment*.

Once per *Scene*, a *Player* may assert that they have a given Prop with them. The prop must make sense in-fiction, and the Player should describe how they came to have this Prop, if not previously determined to be in their possession.

Props do not take up *Inventory* space, and if lost or broken, the Player may not reach for that Prop again until either an in-fiction moment allows it, or until the next *Respite*.

### Leverage Equipment

Your **Inventory** is the list of *Equipment* in your possession. Each *Character* may hold up to 10 pieces of Equipment in their Inventory. *Wielding* Equipment does not remove it from your Inventory. Be thoughtful about which items to pack with you for an adventure!

Any *Equipment* can be **Wielded** to leverage its effects or use it as a weapon. Weapons list their *Damage Rating* and *Talent Affinity* which determine how much damage the weapon deals when attacking, and which Talent to use when making *Attack Rolls* respectively.

Wielding Equipment that does not list a damage rating or talent affinity provides no attack bonuses.

You may wield as many pieces of Equipment as you have available hands. Some Equipment may require two hands to wield.

Not all items need to be Wielded, and some items can even grant bonuses for simply having them in your inventory.

### Rarity

Equipment has **Rarity**, denoting how prized the item itself is.

| Rarity        | Description                                                                                                                                                             |
| ------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Common**    | Something you can find anywhere. A simple knife, a bit of rope, a basic weapon.                                                                                         |
| **Uncommon**  | Halfway decent quality, worth keeping around. A well crafted sword, finely woven rope, a magic wand.                                                                    |
| **Rare**      | Worth seeking out to further your power. The enchanted spear of a fallen hero, a crystal capable of replaying memories, a glove that enhances your ability to pet dogs. |
| **Legendary** | A unique and powerful artifact, often one of a kind. A masterwork from a legendary blacksmith, armor forged in dragon fire, a pocket watch which can stop time.         |

### Barter & Trade

*Proscenium* does not use precise currencies and prices in its economy. Instead, most trading is done through directly bartering with *Equipment* in your *Inventory*, or through the use of **Scales**.

*Scales* are a representation of wealth, with 1 Scale being worth a significant sum. It is rare to hold more than a few Scales at a time.

Gear, food, lodging, and other common transactions are handled in-fiction, rather than tracking each exchange. It is assumed that the *Leads* are able to afford basic adventuring needs.

Examples of what a single Scale can fetch you:

- A *Rare* piece of Equipment
- Luxury lodging in the heart of a city
- A week of a mercenary's time

### Equipment Customization

Equipment in Proscenium can be modified by both *Players* and the *Director* using **Tweaks** and **Tempers**.

A *Tweak* is a neutral or aiding effect added to Equipment. The effect can be anything, such as causing your weapon to be completely silent when you use it, or tweaking some fireworks to make the explosion twice as big. Tweaks cannot change Equipment's *Damage Rating* or *Affinity*.

A *Temper* is a secondary neutral or detracting effect added to Equipment. Tempers are used to counter-balance Tweaks, following the same set of rules. Perhaps your sword was tweaked to be far lighter than usual. A fitting Temper would be that it may shatter if you roll poorly when attacking.

#### Obtaining Tweaks and Tempers

To obtain modifications to *Equipment*, a Player must leverage the help of a skilled NPC or another Player with a relevant *Skill* capable of modifying items.

Typically, it is quite expensive to modify Equipment. It is rare for a skilled craftsman to offer their services for less than the value of a *Rare* item (or a *Scale*) as compensation.

#### Maintaining the Balance

For every *Tweak* applied to a piece of *Equipment*, a *Temper* should also be applied.

When creating Tweaks and Tempers, the Player who owns the Equipment should choose either the Tweak or Temper, while the Director chooses the other. Both should agree on what is fair with the goal of adding a helpful twist to the item at the cost of universal utility.

## Combat & Stage Play

Upon entering combat or a complex scenario, gameplay becomes turn based as we enter **Stage Play**.

While in *Stage Play*, each involved party takes a turn as a group. The active party is *In Action*, while all other parties are *On Cue*.

When your group is *In Action*, your party may perform their Actions in any order. You do not need to use all of your actions before the end of your turn.

While a group is On Cue, their *Cue* Skills can still be triggered.

The *Director* determines the turn order for all parties based on the scenario. For example, if the *Players* are ambushed, the aggressors would have the first move.

### In Action

When your group is **In Action**, your *Character* may perform up to 2 Actions from the list below:

- **Move**, changing *Distance* to a target. If you were *Nearby* a target, you can close the distance to be in *Melee* range, or the other way around.
- Make a **Basic Attack** with your currently equipped weapon(s)
- **Use a Skill**, invoking an Action or Cue from your list of learned Skills
- **Use Equipment**, leveraging the aid of Equipment from your inventory
- **Change Equipment**, switching to a new *Wielded* piece of Equipment. You may equip one piece of Equipment per Action.
- **Interact** with the world, such as opening a door, picking a lock, or snuffing out a torch

### On Cue

While your group is **On Cue**, your *Cues* are active and may be triggered by anything in the ongoing scene.

You may only invoke one *Cue* per round until your next turn *In Action*.

### Damage

*Skills* and *Equipment* may deal *Physical* or *Arcane* damage. Their **Damage Rating** describes the amount and type of damage you will deal upon a *Successful* attack.

**Physical Damage** is dealt when the material body of the target. Slashing with a sword, blowing up with a fireball, or striking with lightning are all examples of Physical Damage. Physical Damage is the most common form of damage, as well as the easier form of damage to mitigate.

**Arcane Damage** is dealt when the Skill or Equipment affects the metaphysical strength of a target. Psychic attacks, dimensional alterations, and unnatural expressions of magic are examples of Arcane Damage. Arcane Damage is harder to mitigate, but is not always as effective as Physical Damage.

### Defense Challenge

A *Character*'s **Defense Challenge** refers to how hard it is to damage them, marking what the *Challenge* an attack roll against them would be.

Without Equipment or Skills, a Character has a default Defense Challenge of *Novice*.

### Dropped

If you sustain enough *Damage* that it meets or surpasses your *Health Points*, you will become **Dropped**.

While Dropped, you are at death's door. You will remain Dropped until the end of the *Scene* or the next moment in-fiction where your *Character* can awaken. If you receive any form of healing while Dropped, you pop back up.

Each time you are Dropped or take damage while Dropped, make a *Fate* roll. If the result is less than the amount of *Baggage* your Character carries, you will perish.

### Baggage

**Baggage** refers to a list of permanent traumas, ailments, conditions, and complications which your *Character* may accrue during gameplay.

Whenever your character is *Dropped* or otherwise severely impacted by mental or physical trauma, gain an additional piece of Baggage. The details of the Baggage and the impacts it has on your Character can be determined between you and the *Director* the next time the party finds *Respite*, unless the effect is immediately obvious or required for fiction, such as losing a body part.

Baggage may have direct mechanical effects such as hindering roll outcomes, or may be permanent personality or physical traits that come into play in fiction.

#### Examples of Baggage

| Scenario                                                                       | Baggage                                                                                                             |
| ------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------- |
| You were blown up by a giant fireball                                          | Your face is now visibly scorched.                                                                                  |
| An evil wizard had control of your mind, sending you into battle as his thrall | You now have difficulty trusting your own perceptions. You can never be certain if what you're seeing is real.      |
| Someone you considered an ally double-crossed you                              | You have trust issues. *Charm* roll outcomes drop by 1 rank.                                                        |
| You are sliced up real bad                                                     | You lose a limb                                                                                                     |
| You swashbuckled a bit too hard and lost a pirate swordfight                   | Your character now wears an eyepatch. Your depth perception is hindered, making ranged attack rolls drop by 1 rank. |

### Distance

**Distance** is categorized into the following groups based on the relative space between entities.

| Category     | Distance       | Description                                                 |
| ------------ | -------------- | ----------------------------------------------------------- |
| **Melee**    | 5ft / 1.5m     | Close enough to bash them with a rock                       |
| **Nearby**   | 25ft / 7.5m    | Close enough to throw a rock at 'em                         |
| **In Range** | 100ft / 30m    | Close enough to throw a rock at 'em if you've got great aim |
| **Distant**  | \>100ft / >30m | Too far to hit with a rock, which is a shame                |

## Rest & Recovery

### Rest

You may choose to **Rest** on your journey in a safe location. Resting takes 1 hour and costs each *Character* 1 *Exhaustion Point*. If you do not have any available EP, your character does not benefit from a Rest.

Upon completing a Rest, remove up to 5 points of accrued *Damage* and regain all of your *Skill Points*.

Some *Skills* may provide additional effects which occur on Rest.

### Respite

When you are able to find a secure location to rest for at least a full day, you have found **Respite**.

This must be a scenario in which your character does not need to be "on" for a full day.

At the end of the respite, you remove all accrued *Damage* and restore all *Skill Points* and *Exhaustion Points*.

Respite can be as short as 24 hours, or as long as it takes. Adventuring is a full time job, but sometimes vacations are necessary. Explore other aspects of your Character's life during Respite to deepen your connection.

## Glossary

### A

- **Adept**: The middle level of Prowess in a Talent
- **Affinity**: Determines which Talent is associated with a piece of Equipment, usually what you will roll to attack with it

### B

- **Baggage**: A permanent detrimental trait for a Character acquired when being Dropped
- **Basic Attack**: Making a simple attack unarmed or with a weapon

### C

- **Character**: An in-fiction entity controlled by a Player
- **Charm**: A Talent used for mingling and interpersonal skills
- **Common**: The lowest Equipment Rarity
- **Complication**: A wrinkle in the story which occurs when attempting a Roll whose Challenge is higher than your Prowess
- **Cunning**: A Talent used for quick thinking and deft hands

### D

- **Damage**: A number representing how much a Character been hurt
- **Director**: Responsible for weaving Player actions into a cohesive story. Sometimes referred to as the "Game Master" in other systems
- **Dropped**: Refers to a Character sustaining enough Damage to fall unconscious

### E

- **Equipment**: Gear in your Inventory which can be used or equipped
- **Exhaustion Points**: A Character Stat which determines how hard you can push yourself during adventure
- **Experience Points**: A Character Stat used to unlock new Abilities

### F

- **Fate Roll**: A basic D20 Roll to determine outcomes outside of the influence of Players and their Characters
- **Focus**: A Talent used for observation and precision

### H

- **Health Points**: A Character Stat which determines how much Damage can be sustained before becoming Dropped

### I

- **Inventory**: The list of Equipment a Character owns

### K

- **Knowledge**: A Talent used for recollection and comprehension

### L

- **Legendary**: The highest Equipment Rarity

### M

- **Master**: The highest level of Prowess in a Talent
- **Method**: A collection of Skills a Character can unlock
- **Mishap**: A failed Roll outcome
- **Muscle**: A Talent used for feats of strength and resilience

### N

- **Novice**: The lowest level of Prowess in a Talent

### P

- **Player**: Responsible for playing a Character in the story
- **Prop**: Small items which do not need to be tracked in your Inventory
- **Prowess**: How good a Character is at a Talent. Determines how many dice to roll when rolling for that Talent.

### R

- **Rare**: The second highest Equipment Rarity
- **Rarity**: Measurement of how unique or coveted a piece of Equipment is
- **Respite**: A fully restorative break lasting at least 24 hours
- **Rest**: A quick break to restore some energy while out adventuring

### S

- **Scale**: An abstract unit of currency equivalent to a large sum of money
- **Scene**: A segment of the storytelling at the Table
- **Skill**: An unlockable upgrade for a Character
- **Skill Points**: A Character Stat which determines how many Skills can be used before needing to Rest
- **Snag**: A Roll Outcome representing a mixed outcome. You succeed at your task alongside a Bane.
- **Spark**: A Talent used for connection to the arcane or otherworldly power
- **Species**: Generally refers to a selectable species as the base for a playable Character. Sometimes referred to as "race" in other systems
- **Stage Play**: Proscenium's approach to turn-based gameplay
- **Stat**: A numeric attribute of a Character defining various traits of the Character
- **Success**: A successful roll outcome

### T

- **Talent**: One of six measurements of a Character's general skillset

### U

- **Uncommon**: The second lowest Equipment Rarity

